<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2011, Oxwall Foundation
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Oxwall Foundation nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * @author Podyachev Evgeny <joker.OW2@gmail.com>
 * @package ow_plugins.privacy
 * @since 1.0
 */
$plugin = OW::getPluginManager()->getPlugin('privacy');

$router->addRoute(new OW_Route('privacy_index', 'profile/privacy', 'PRIVACY_CTRL_Privacy', 'index'));
$router->addRoute(new OW_Route('privacy_no_permission', 'privacy/:username/no-permission', 'PRIVACY_CTRL_Privacy', 'noPermission'));

function privacy_dashboard_menu_item( BASE_CLASS_EventCollector $event )
{
    $router = OW_Router::getInstance();
    $language = OW::getLanguage();

    $menuItem = new BASE_MenuItem();

    $menuItem->setKey('privacy');
    $menuItem->setLabel($language->text('privacy', 'privacy_index'));
    $menuItem->setIconClass('ow_ic_lock');
    $menuItem->setUrl($router->urlForRoute('privacy_index'));
    $menuItem->setOrder(5);

    $event->add($menuItem);
}
OW::getEventManager()->bind('base.dashboard_menu_items', 'privacy_dashboard_menu_item');

function privacy_add_privacy( BASE_CLASS_EventCollector $event )
{
    $language = OW::getLanguage();
    $params = $event->getParams();

    $event->add(array(
        'key' => 'everybody',
        'label' => $language->text('privacy', 'privacy_everybody'),
        'weight' => 0,
        'sortOrder' => 0
    ));

    $event->add(array(
        'key' => 'only_for_me',
        'label' => $language->text('privacy', 'privacy_only_for_me'),
        'weight' => 10,
        'sortOrder' => 100000
    ));
}

OW::getEventManager()->bind(PRIVACY_BOL_ActionService::EVENT_GET_PRIVACY_LIST, 'privacy_add_privacy');

function privacy_get_action_privacy( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['ownerId']) || empty($params['action']) )
    {
        throw new InvalidArgumentException('Invalid parameters were provided!'); // TODO trow Exeption
    }

    return PRIVACY_BOL_ActionService::getInstance()->getActionValue($params['action'], $params['ownerId']);
}

OW::getEventManager()->bind('plugin.privacy.get_privacy', 'privacy_get_action_privacy');

function privacy_get_action_main_privacy_by_owner_id_list( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['userIdList']) || !is_array($params['userIdList']) || empty($params['action']) )
    {
        throw new InvalidArgumentException('Invalid parameters were provided!'); // TODO trow Exeption
    }

    return PRIVACY_BOL_ActionService::getInstance()->getMainActionValue($params['action'], $params['userIdList']);
}

OW::getEventManager()->bind('plugin.privacy.get_main_privacy', 'privacy_get_action_main_privacy_by_owner_id_list');

function privacy_remove_user_privacy( OW_Event $event )
{
    $params = $event->getParams();

    $userId = (int) $params['userId'];
    PRIVACY_BOL_ActionService::getInstance()->deleteActionDataByUserId($userId);
}

OW::getEventManager()->bind(OW_EventManager::ON_USER_UNREGISTER, 'privacy_remove_user_privacy');

function privacy_remove_plugin_privacy( OW_Event $event )
{
    $params = $event->getParams();

    if ( !empty($params['pluginKey']) )
    {
        PRIVACY_BOL_ActionService::getInstance()->deleteActionDataByPluginKey($params['pluginKey']);
    }
}

OW::getEventManager()->bind(OW_EventManager::ON_BEFORE_PLUGIN_UNINSTALL, 'privacy_remove_plugin_privacy');

function privacy_check_premission( OW_Event $event )
{
    
    $params = $event->getParams();

    $result = PRIVACY_BOL_ActionService::getInstance()->checkPermission($params);
    
    if ( $result['blocked'] )
    {
        $ownerId = (int)$params['ownerId'];

        $username = BOL_UserService::getInstance()->getUserName($ownerId);
        
        $exception = new RedirectException( OW::getRouter()->urlForRoute('privacy_no_permission', array( 'username' => $username )) );

        $params['message'] = $result['message'];
        $params['privacy'] = $result['privacy'];
        
        OW::getSession()->set('privacyRedirectExceptionMessage', $params['message']);

        $exception->setData($params);
        
        throw $exception;
    }
}

OW::getEventManager()->bind(PRIVACY_BOL_ActionService::EVENT_CHECK_PERMISSION, 'privacy_check_premission');

function privacy_permission_everybody( BASE_CLASS_EventCollector $event )
{
    $params = $event->getParams();

    if( !empty($params['privacy']) && $params['privacy'] == 'everybody' )
    {
        $privacy = array();
        $privacy = array(
            'everybody' => array(
                       'blocked' => false

        ) );

        $event->add($privacy);
    }
}

OW::getEventManager()->bind('plugin.privacy.check_permission', 'privacy_permission_everybody');

function privacy_permission_only_for_me( BASE_CLASS_EventCollector $event )
{
    $language = OW::getLanguage();

    $params = $event->getParams();

    if( !empty($params['privacy']) && $params['privacy'] == 'only_for_me' )
    {
        $ownerId = (int) $params['ownerId'];
        $viewerId = (int)  $params['viewerId'];
        
        $privacy = array();
        $privacy = array(
            'only_for_me' => array(
                       'blocked' => true,

        ) );

        if ( $ownerId > 0 && $ownerId === $viewerId )
        {
            $privacy = array(
                'only_for_me' => array(
                           'blocked' => false

            ) );
        }

        $event->add($privacy);
    }
}

OW::getEventManager()->bind('plugin.privacy.check_permission', 'privacy_permission_only_for_me');

function privacy_plugin_is_active()
{
    return true;
}

OW::getEventManager()->bind('plugin.privacy', 'privacy_plugin_is_active');

